pub struct AuthorizationFlow { /* private fields */ }Expand description
The OAuth 2.0 authorization code flow with PKCE.
Implementations
Sourceimpl AuthorizationFlow
impl AuthorizationFlow
pub fn new( config: OAuthConfig, http: Arc<dyn HttpClient>, clock: Arc<dyn Clock>, ) -> Self
Sourcepub fn begin(
&self,
redirect_uri: impl Into<String>,
) -> Result<PendingAuthorization>
pub fn begin( &self, redirect_uri: impl Into<String>, ) -> Result<PendingAuthorization>
Build the URL to send the user to.
redirect_uri comes from an already-listening RedirectListener.
Sourcepub async fn exchange(
&self,
pending: &PendingAuthorization,
code: &AuthorizationCode,
) -> Result<TokenSet>
pub async fn exchange( &self, pending: &PendingAuthorization, code: &AuthorizationCode, ) -> Result<TokenSet>
Trade the authorization code for tokens.
Sourcepub async fn refresh(&self, refresh_token: &str) -> Result<TokenSet>
pub async fn refresh(&self, refresh_token: &str) -> Result<TokenSet>
Exchange a refresh token for a new access token.
Run the whole flow: open the browser, wait for the redirect, exchange the code.